/**
 * 请假逻辑
 * 作者:lxm
 * 包括工时填报
 */

import moment = require("moment");
import { ASKFORLEAVETYPE } from "../config/enum";
import { addData, selectData } from "../data/admin/askForLeave";
import * as tools from "../util/tools";


/**
 * 请假
 * @param des 描述 
 * @param startTime 开始时间 
 * @param endTime 结束时间
 * @param long 时长
 * @param type 请假类型
 */

/**
 * 添加请假记录
 * @param userId 填报人
 * @param desc 描述
 * @param startTime 开始请假时间
 * @param endTime 结束请假时间
 * @param type 请假类型
 * @param date 填报时间
 * @returns {isSuccess:true, message:"添加成功"}
 */
export async function askForLeave(userId:string, desc:string, startTime:number, endTime:number, type:number, date:string) {
    const DateKey = tools.getWorkingDateKey(date);

    let st = new Date(startTime);
    let et = new Date(endTime);

    await addData(desc, st, et, userId, type, DateKey);

    return {isSuccess:true, message:"添加成功"};
}


export async function myAskForLeaveList(userId:string) {
    let dataList = await selectData(userId);

    let result = [];
    dataList.forEach(info => {
        let { id, des, startTime, endTime, time, type, day } = info;
        let changeType = tools.changeEnumValue(ASKFORLEAVETYPE, type);
        let changeStartTime = moment(startTime).format("YYYY/MM/DD HH:mm");
        let changeEndTimee = moment(endTime).format("YYYY/MM/DD HH:mm");
        let timeStr = `${day}日${time}小时`;
        result.push({id, des, startTime:changeStartTime, endTime:changeEndTimee, time:timeStr, type:changeType});
    });

    return {dataList:result}
}
